# zoomies

![logo](docs/zoomies.png)

Stars get the zoomies too. This is a dynamical age prediction package that uses Gaia parallax, proper motion, and radial velocity along with a Milky Way potential model to produce a stellar age prediction based on its galactic orbit.

The documentation for `zoomies` is hosted at https://zoomies.readthedocs.io/en/latest/. See the documentation for tutorials, usage examples, and more!

For detailed information, read our paper: [Sagear et al. 2024](https://iopscience.iop.org/article/10.3847/1538-4357/ad8b26)

To use zoomies, install it using pip:

```
pip install zoomies
```